Composed permissions for django-rest-framework
----------------------------------------------

A simple way to define complex permissions for django-rest-framework.

- **Documentation:** https://djangorestframework-composed-permissions.readthedocs.org/en/latest/

License
-------

New BSD License
